@@ -29,11 +29,12 @@ Utilities for documenting functions, classes and methods.
 # stdlib
 import builtins
 import platform
-from textwrap import dedent
+from inspect import cleandoc
 from types import MethodType
 from typing import Any, Callable, Dict, Optional, Sequence, Type, TypeVar, Union
 
 # this package
+from domdf_python_tools.stringlist import StringList
 from domdf_python_tools.typing import MethodDescriptorType, MethodWrapperType, WrapperDescriptorType
 
 __all__ = [
@@ -102,13 +103,16 @@ def append_doctring_from_another(target: Union[Type, Callable], original: Union[
 	original_doc = original.__doc__
 
 	if isinstance(original_doc, str) and isinstance(target_doc, str):
-		deindented_target_doc = dedent(target_doc)
-		deindented_original_doc = dedent(original_doc)
-
-		target.__doc__ = deindented_target_doc + "\n" + deindented_original_doc
+		docstring = StringList(cleandoc(target_doc))
+		docstring.blankline(ensure_single=True)
+		docstring.append(cleandoc(original_doc))
+		docstring.blankline(ensure_single=True)
+		target.__doc__ = str(docstring)
 
 	elif not isinstance(target_doc, str) and isinstance(original_doc, str):
-		target.__doc__ = dedent(original_doc)
+		docstring = StringList(cleandoc(original_doc))
+		docstring.blankline(ensure_single=True)
+		target.__doc__ = str(docstring)
 
 
 def make_sphinx_links(input_string: str, builtins_list: Optional[Sequence[str]] = None) -> str:
@@ -134,8 +138,8 @@ def make_sphinx_links(input_string: str, builtins_list: Optional[Sequence[str]]
 	:param builtins_list: A list of builtins to make links for.
 	:default builtins_list: dir(:py:obj:`builtins`)
 
-	:return: processed string with links
-	"""
+	:return: Processed string with links.
+	"""  # noqa SXL001
 
 	if builtins_list is None:
 		builtins_list = dir(builtins)
@@ -199,7 +203,7 @@ def sphinxify_docstring() -> Callable:
 
 	Make sure to have ``'python': ('https://docs.python.org/3/', None),`` in the
 	``intersphinx_mapping`` dict of your ``conf.py`` file for Sphinx.
-	"""
+	"""  # noqa SXL001
 
 	def wrapper(target: F) -> F:
 		target_doc = target.__doc__
@@ -307,7 +311,7 @@ def _do_prettify(obj: Type, base: Type, new_docstrings: Dict[str, str]):
 	:param base:
 	:param new_docstrings:
 
-	:return:
+	:rtype:
 
 	.. versionadded:: 0.8.0
 	"""
@@ -370,4 +374,7 @@ def prettify_docstrings(obj: Type) -> Type:
 			except AttributeError:  # pragma: no cover
 				pass
 
+	if issubclass(obj, tuple) and obj.__repr__.__doc__ == "Return a nicely formatted representation string":
+		obj.__repr__.__doc__ = repr_docstring
+
 	return obj
